#!/bin/sh
set -e
## nbscript.sh 5.3.3 - Download netboot images and launch them with kexec
## Copyright (C) 2014 Isaac Schemm <isaacschemm@gmail.com>
##
## This program is free software; you can redistribute it and/or
## modify it under the terms of the GNU General Public License
## as published by the Free Software Foundation; either version 2
## of the License, or (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
##
## The full text of the GNU GPL, versions 2 or 3, can be found at
## <http://www.gnu.org/copyleft/gpl.html>, on the NetbootCD site at
## <http://netbootcd.tuxfamily.org>, or on the CD itself.

TITLE="NetbootCD Script 5.3.3 - June 21, 2014"

getversion ()
{
	#This function reads the version the user selected from /tmp/nb-version and stores it in the VERSION variable, then deletes /tmp/nb-version.
	VERSION=$(cat /tmp/nb-version)
	if [ $VERSION = "Manual" ];then
		dialog --backtitle "$TITLE" --inputbox "Specify your preferred version here.\nFor Ubuntu and Debian, use the codename. For other distributions, use the version number." 11 54 2>/tmp/nb-version
		VERSION=$(cat /tmp/nb-version)
	fi
	rm /tmp/nb-version
}


askforopts ()
{
#Extra kernel options can be useful in some cases; i.e. hardware problems, Debian preseeding, or maybe you just want to utilise your whole 1280x1024 monitor (use: vga=794).
dialog --backtitle "$TITLE" --inputbox "Would you like to pass any extra kernel options?\n(Note: it is OK to leave this field blank)\nUse the syntax: --append=option1=asdf --append=option2=hi" 9 64 2>/tmp/nb-custom
CUSTOM=$(cat /tmp/nb-custom)
rm /tmp/nb-custom
}


installmenu ()
{
#Ask the user to choose a distro, save the choice to /tmp/nb-distro
dialog --backtitle "$TITLE" --menu "Choose a distribution:" 20 70 13 \
ubuntu "Ubuntu" \
ubuntu64 "Ubuntu (amd64)" \
debian "Debian GNU/Linux" \
debian64 "Debian GNU/Linux (amd64)" \
debiandaily "Debian GNU/Linux - daily installers" \
fedora "Fedora" \
fedora64 "Fedora (x86_64)" \
opensuse "openSUSE" \
opensuse64 "openSUSE (x86_64)" \
mandriva "Mandriva Linux" \
rhel-type "CentOS and Scientific Linux (newest)" \
rhel-type-64 "CentOS and Scientific Linux (newest, x86_64)" \
rhel-type-5 "CentOS and Scientific Linux (version 5)" \
slackware "Slackware" 2>/tmp/nb-distro
#Read their choice, save it, and delete the old file
DISTRO=$(cat /tmp/nb-distro)
rm /tmp/nb-distro
#Now to check which distro the user picked.
if [ $DISTRO = "ubuntu" ];then
	#Ask about version
	dialog --menu "Choose a system to install:" 20 70 13 \
	trusty "Ubuntu 14.04 LTS" \
	saucy "Ubuntu 13.10" \
	raring "Ubuntu 13.04" \
	Manual "Manually enter a version to install" 2>/tmp/nb-version
	#Run the getversion() function above
	getversion

	#Set the URL to download the kernel and initrd from. The server used here is archive.ubuntu.com.
	KERNELURL="http://archive.ubuntu.com/ubuntu/dists/$VERSION-updates/main/installer-i386/current/images/netboot/ubuntu-installer/i386/linux"
	INITRDURL="http://archive.ubuntu.com/ubuntu/dists/$VERSION-updates/main/installer-i386/current/images/netboot/ubuntu-installer/i386/initrd.gz"
	# Test if distro-updates exists
	if ! wget --spider -q $KERNELURL; then # fallback to known distro
		KERNELURL="http://archive.ubuntu.com/ubuntu/dists/$VERSION/main/installer-i386/current/images/netboot/ubuntu-installer/i386/linux"
		INITRDURL="http://archive.ubuntu.com/ubuntu/dists/$VERSION/main/installer-i386/current/images/netboot/ubuntu-installer/i386/initrd.gz"
	fi
	#These options are good for all Ubuntu installers.
	echo -n '--append=vga=normal --append=quiet '>>/tmp/nb-options
	#If the user wants a command-line install, then add some more kernel arguments. The CLI install is akin to "standard system" in Debian.
	if ! dialog --yesno "Would you like to install language packs?\n(Choose no for a command-line system.)" 6 43;then
		#These arguments appear to just prevent the system from installing language packs. Not sure if they work, but Ubuntu's mini.iso has them.
		echo -n '--append=tasks=standard --append=pkgsel/language-pack-patterns= --append=pkgsel/install-language-support=false'>>/tmp/nb-options
	fi
fi
if [ $DISTRO = "ubuntu64" ];then
	#Ask about version
	dialog --menu "Choose a system to install:" 20 70 13 \
	trusty "Ubuntu 14.04 LTS" \
	saucy "Ubuntu 13.10" \
	raring "Ubuntu 13.04" \
	Manual "Manually enter a version to install" 2>/tmp/nb-version
	#Run the getversion() function above
	getversion

	#Set the URL to download the kernel and initrd from. The server used here is archive.ubuntu.com.
	KERNELURL="http://archive.ubuntu.com/ubuntu/dists/$VERSION-updates/main/installer-amd64/current/images/netboot/ubuntu-installer/amd64/linux"
	INITRDURL="http://archive.ubuntu.com/ubuntu/dists/$VERSION-updates/main/installer-amd64/current/images/netboot/ubuntu-installer/amd64/initrd.gz"
	# Test if distro-updates exists
	if ! wget --spider -q $KERNELURL; then # fallback to known distro
		KERNELURL="http://archive.ubuntu.com/ubuntu/dists/$VERSION/main/installer-amd64/current/images/netboot/ubuntu-installer/amd64/linux"
		INITRDURL="http://archive.ubuntu.com/ubuntu/dists/$VERSION/main/installer-amd64/current/images/netboot/ubuntu-installer/amd64/initrd.gz"
	fi
	#These options are good for all Ubuntu installers.
	echo -n '--append=vga=normal --append=quiet '>>/tmp/nb-options
	#If the user wants a command-line install, then add some more kernel arguments. The CLI install is akin to "standard system" in Debian.
	if ! dialog --yesno "Would you like to install language packs?\n(Choose no for a command-line system.)" 6 43;then
		echo -n '--append=tasks=standard --append=pkgsel/language-pack-patterns= --append=pkgsel/install-language-support=false'>>/tmp/nb-options
	fi
fi
if [ $DISTRO = "debian" ];then
	dialog --backtitle "$TITLE" --menu "Choose a system to install:" 20 70 13 \
	stable "Debian stable" \
	testing "Debian testing" \
	Manual "Manually enter a version to install" 2>/tmp/nb-version
	getversion
	KERNELURL="http://http.us.debian.org/debian/dists/$VERSION/main/installer-i386/current/images/netboot/debian-installer/i386/linux"
	INITRDURL="http://http.us.debian.org/debian/dists/$VERSION/main/installer-i386/current/images/netboot/debian-installer/i386/initrd.gz"
	echo -n '--append=vga=normal --append=quiet '>>/tmp/nb-options
	#Testing and unstable use the same kernel. See: https://wiki.debian.org/DebianUnstable#How_do_I_install_Sid.3F
fi
if [ $DISTRO = "debian64" ];then
	dialog --backtitle "$TITLE" --menu "Choose a system to install:" 20 70 13 \
	stable "Debian stable" \
	stable-expert "Debian stable (expert mode)" \
	testing "Debian testing" \
	testing-expert "Debian testing (expert mode)" \
	Manual "Manually enter a version to install" 2>/tmp/nb-version
	getversion
	KERNELURL="http://http.us.debian.org/debian/dists/$VERSION/main/installer-amd64/current/images/netboot/debian-installer/amd64/linux"
	INITRDURL="http://http.us.debian.org/debian/dists/$VERSION/main/installer-amd64/current/images/netboot/debian-installer/amd64/initrd.gz"
	echo -n '--append=vga=normal --append=quiet" '>>/tmp/nb-options
fi
if [ $DISTRO = "debiandaily" ];then
	dialog --backtitle "$TITLE" --menu "Choose a system to install:" 20 70 13 \
	testing "Debian testing" \
	testing-expert "Debian testing/unstable (expert mode)" \
	Manual "Manually enter a version to install" 2>/tmp/nb-version
	getversion
	KERNELURL="http://d-i.debian.org/daily-images/i386/daily/netboot/debian-installer/i386/linux"
	INITRDURL="http://d-i.debian.org/daily-images/i386/daily/netboot/debian-installer/i386/initrd.gz"
	echo -n '--append=vga=normal --append=quiet '>>/tmp/nb-options
	if [ $VERSION = "testing-expert" ];then
		echo -n '--append=expert '>>/tmp/nb-options
	fi
fi
if [ $DISTRO = "fedora" ];then
	dialog --backtitle "$TITLE" --menu "Choose a system to install:" 20 70 13 \
	20 "Fedora 20" \
	19 "Fedora 19" \
	18 "Fedora 18" \
	development "Rawhide" \
	Manual "Manually enter a version to install" 2>/tmp/nb-version
	getversion
	#All Fedora releases are in "releases" and have a "Fedora" directory.
	if [ $VERSION != "development" ];then
		VERSION=releases/$VERSION/Fedora
	fi
	#Ask the user which server to use (the installer doesn't have a built-in list like Ubuntu and Debian do.)
	dialog --inputbox "Where do you want to install Fedora from?" 8 70 "http://mirrors.kernel.org/fedora/releases/20/Fedora/i386/os/" 2>/tmp/nb-server
	KERNELURL="$(cat /tmp/nb-server)/images/pxeboot/vmlinuz"
	INITRDURL="$(cat /tmp/nb-server)/images/pxeboot/initrd.img"
	echo -n "--append=inst.repo=$(cat /tmp/nb-server)" >>/tmp/nb-options
	rm /tmp/nb-server
fi
if [ $DISTRO = "fedora64" ];then
	dialog --backtitle "$TITLE" --menu "Choose a system to install:" 20 70 13 \
	20 "Fedora 20 (64-bit)" \
	19 "Fedora 19 (64-bit)" \
	18 "Fedora 18 (64-bit)" \
	development "Rawhide" \
	Manual "Manually enter a version to install" 2>/tmp/nb-version
	getversion
	#All Fedora releases are in "releases" and have a "Fedora" directory.
	if [ $VERSION != "development" ];then
		VERSION=releases/$VERSION/Fedora
	fi
	#Ask the user which server to use (the installer doesn't have a built-in list like Ubuntu and Debian do.)
	dialog --inputbox "Where do you want to install Fedora from?" 8 70 "http://mirrors.kernel.org/fedora/releases/20/Fedora/i386/os/" 2>/tmp/nb-server
	KERNELURL="$(cat /tmp/nb-server)/images/pxeboot/vmlinuz"
	INITRDURL="$(cat /tmp/nb-server)/images/pxeboot/initrd.img"
	echo -n "--append=inst.repo=$(cat /tmp/nb-server)" >>/tmp/nb-options
	rm /tmp/nb-server
fi
if [ $DISTRO = "opensuse" ];then
	dialog --backtitle "$TITLE" --menu "Choose a system to install:" 20 70 13 \
	13.1 "openSUSE 13.1" \
	12.3 "openSUSE 12.3" \
	12.2 "openSUSE 12.2" \
	12.1 "openSUSE 12.1" \
	factory "openSUSE factory" \
	Manual "Manually enter a version to install" 2>/tmp/nb-version
	getversion
	#All versions of openSUSE are in the "distribution" folder, except for factory.
	if [ $VERSION != "factory" ];then
		VERSION=distribution/$VERSION
	fi
	KERNELURL="http://download.opensuse.org/$VERSION/repo/oss/boot/i386/loader/linux"
	INITRDURL="http://download.opensuse.org/$VERSION/repo/oss/boot/i386/loader/initrd"
	#These options are common to openSUSE.
	echo -n '--append=splash=silent --append=showopts '>>/tmp/nb-options
	#Ask the user which server to use (the installer doesn't have a built-in list like Ubuntu and Debian do.)
	dialog --inputbox "Where do you want to install openSUSE from?" 8 70 http://download.opensuse.org/$VERSION/repo/oss 2>/tmp/nb-server
	echo -n "--append=install=$(cat /tmp/nb-server)" >>/tmp/nb-options
	rm /tmp/nb-server
fi
if [ $DISTRO = "opensuse64" ];then
	dialog --backtitle "$TITLE" --menu "Choose a system to install:" 20 70 13 \
	13.1 "openSUSE 13.1" \
	12.3 "openSUSE 12.3" \
	12.2 "openSUSE 12.2" \
	12.1 "openSUSE 12.1" \
	factory "openSUSE factory" \
	Manual "Manually enter a version to install" 2>/tmp/nb-version
	getversion
	#All versions of openSUSE are in the "distribution" folder, except for factory.
	if [ $VERSION != "factory" ];then
		VERSION=distribution/$VERSION
	fi
	KERNELURL="http://download.opensuse.org/$VERSION/repo/oss/boot/x86_64/loader/linux"
	INITRDURL="http://download.opensuse.org/$VERSION/repo/oss/boot/x86_64/loader/initrd"
	#These options are common to openSUSE.
	echo -n '--append=splash=silent --append=showopts '>>/tmp/nb-options
	#Ask the user which server to use (the installer doesn't have a built-in list like Ubuntu and Debian do.)
	dialog --inputbox "Where do you want to install openSUSE from?" 8 70 http://download.opensuse.org/$VERSION/repo/oss 2>/tmp/nb-server
	echo -n "--append=install=$(cat /tmp/nb-server)" >>/tmp/nb-options
	rm /tmp/nb-server
fi
if [ $DISTRO = "mandriva" ];then
	dialog --backtitle "$TITLE" --menu "Choose a system to install:" 20 70 13 \
	current "Current version" \
	2011 "Mandriva Linux 2011" \
	cooker "Cooker" \
	Manual "Manually enter a version to install" 2>/tmp/nb-version
	getversion
	#All versions of openSUSE are in the "official" folder, except for cooker which is in "devel".
	if [ $VERSION = "cooker" ];then
		VERSION=devel/cooker
	else
		VERSION=official/$VERSION
	fi
	KERNELURL="http://www.gtlib.gatech.edu/pub/mandrake/$VERSION/i586/isolinux/alt0/vmlinuz"
	INITRDURL="http://www.gtlib.gatech.edu/pub/mandrake/$VERSION/i586/isolinux/alt0/all.rdz"
	#These options are common to Mandriva.
	echo -n '--append=vga=788 --append=splash=silent --append=automatic=method:http'>>/tmp/nb-options
fi
if [ $DISTRO = "rhel-type" ];then
	dialog --backtitle "$TITLE" --menu "Choose a system to install:" 20 70 13 \
	s_6 "Latest version of Scientific Linux 6" \
	s_6.5 "Scientific Linux 6.5" \
	c_6 "Latest version of CentOS 6" \
	c_6.5 "CentOS 6.5" \
	Manual "Manually enter a version to install (prefix with s_ or c_)" 2>/tmp/nb-version
	getversion
	TYPE=$(echo $VERSION|head -c 1)
	VERSION=$(echo $VERSION|tail -c +3)
	#Ask the user which server to use (the installer doesn't have a built-in list like Ubuntu and Debian do.)
	if [ $TYPE = s ];then
		dialog --inputbox "Where do you want to install Scientific Linux from?" 8 70 "ftp://linux1.fnal.gov/linux/scientific/$VERSION/i386/os" 2>/tmp/nb-server
	else
		dialog --inputbox "Where do you want to install CentOS from?" 8 70 "http://mirrors.kernel.org/centos/$VERSION/os/i386" 2>/tmp/nb-server
	fi
	SERVER=$(cat /tmp/nb-server)
	KERNELURL="$SERVER/isolinux/vmlinuz"
	INITRDURL="$SERVER/isolinux/initrd.img"
	echo -n "--append=ide=nodma --append=method=$(cat /tmp/nb-server)" >>/tmp/nb-options
	rm /tmp/nb-server
	askforopts
fi
if [ $DISTRO = "rhel-type-64" ];then
	dialog --backtitle "$TITLE" --menu "Choose a system to install:" 20 70 13 \
	s_6 "Latest version of Scientific Linux 6" \
	s_6.5 "Scientific Linux 6.5" \
	c_6 "Latest version of CentOS 6" \
	c_6.5 "CentOS 6.5" \
	Manual "Manually enter a version to install (prefix with s_ or c_)" 2>/tmp/nb-version
	getversion
	TYPE=$(echo $VERSION|head -c 1)
	VERSION=$(echo $VERSION|tail -c +3)
	#Ask the user which server to use (the installer doesn't have a built-in list like Ubuntu and Debian do.)
	if [ $TYPE = s ];then
		dialog --inputbox "Where do you want to install Scientific Linux from?" 8 70 "ftp://linux1.fnal.gov/linux/scientific/$VERSION/x86_64/os" 2>/tmp/nb-server
	else
		dialog --inputbox "Where do you want to install CentOS from?" 8 70 "http://mirrors.kernel.org/centos/$VERSION/os/x86_64" 2>/tmp/nb-server
	fi
	SERVER=$(cat /tmp/nb-server)
	KERNELURL="$SERVER/isolinux/vmlinuz"
	INITRDURL="$SERVER/isolinux/initrd.img"
	echo -n "--append=ide=nodma --append=method=$(cat /tmp/nb-server)" >>/tmp/nb-options
	rm /tmp/nb-server
	askforopts
fi
if [ $DISTRO = "rhel-type-5" ];then
	dialog --backtitle "$TITLE" --menu "Choose a system to install:" 20 70 13 \
	s_5 "Latest version of Scientific Linux 5" \
	s_5.10 "Scientific Linux 5.10" \
	c_5 "Latest version of CentOS 5" \
	c_5.10 "CentOS 5.10" \
	Manual "Manually enter a version to install (prefix with s_ or c_)" 2>/tmp/nb-version
	getversion
	TYPE=$(echo $VERSION|head -c 1)
	VERSION=$(echo $VERSION|tail -c +3)
	#Ask the user which server to use (the installer doesn't have a built-in list like Ubuntu and Debian do.)
	if [ $TYPE = s ];then
		VERSION=$(echo $VERSION|sed -e 's/\.//g')
		dialog --inputbox "Where do you want to install Scientific Linux from?" 8 70 "http://linux1.fnal.gov/linux/scientific/$VERSION/i386" 2>/tmp/nb-server
	else
		dialog --inputbox "Where do you want to install CentOS from?" 8 70 "http://mirrors.kernel.org/centos/$VERSION/os/i386" 2>/tmp/nb-server
	fi
	SERVER=$(cat /tmp/nb-server)
	KERNELURL="$SERVER/isolinux/vmlinuz"
	INITRDURL="$SERVER/isolinux/initrd.img"
	echo -n "--append=method=$(cat /tmp/nb-server)" >>/tmp/nb-options
	rm /tmp/nb-server
fi
if [ $DISTRO = "slackware" ];then
	SLACKASK="Slackware can't be installed from a web server.\nContinue?"
	if ! dialog --yesno "$SLACKASK" 0 0;then exec $0 $*;fi #Go back to main menu if no
	dialog --backtitle "$TITLE" --menu "Choose a system to install:" 20 70 13 \
	slackware-14.1 "Slackware 14.1 (32-bit)" \
	slackware64-14.1 "Slackware 14.1 (64-bit)" \
	current "Slackware-current" \
	Manual "Manually enter a version to install" 2>/tmp/nb-version
	getversion
	dialog --backtitle "$TITLE" --menu "Choose a kernel type:" 20 70 13 \
	huge.s "" \
	hugesmp.s "" 2>/tmp/nb-kerntype
	KERNTYPE=$(cat /tmp/nb-kerntype)
	rm /tmp/nb-kerntype
	KERNELURL="http://slackware.cs.utah.edu/pub/slackware/$VERSION/kernels/$KERNTYPE/bzImage"
	INITRDURL="http://slackware.cs.utah.edu/pub/slackware/$VERSION/isolinux/initrd.img"
	echo -n "--append=load_ramdisk=1 --append=prompt_ramdisk=0 --append=rw --append=SLACK_KERNEL=$KERNTYPE" >>/tmp/nb-options
fi
OPTIONS=$(cat /tmp/nb-options)
rm /tmp/nb-options
#Now download the kernel and initrd.
wget $KERNELURL -O /tmp/nb-linux
wget $INITRDURL -O /tmp/nb-initrd
}

utilsmenu ()
{
#Ask the user to choose a distro, save the choice to /tmp/nb-distro
dialog --backtitle "$TITLE" --menu "Choose a utility:" 20 70 13 \
grub4dos "GRUB4DOS - a versitle bootloader that can be loaded from kexec" \
core "Core (formerly Micro Core) - very small but extensible Linux distribution" \
tinycore "Tiny Core" \
gparted "Tiny Core (also try to download GParted)" 2>/tmp/nb-distro
#Read their choice, save it, and delete the old file
DISTRO=$(cat /tmp/nb-distro)
rm /tmp/nb-distro
#What version?
if [ $DISTRO = "grub4dos" ];then
	dialog --backtitle "$TITLE" --menu "Choose a version to download:" 20 70 13 \
	0.4.6a-2014-01-17 "grub4dos-chenall fork (0.4.6a branch)" \
	0.4.5c-2014-01-17 "grub4dos-chenall fork (0.4.5c branch)" \
	0.4.4-2009-06-20 "Latest version of original - June 6, 2009" 2>/tmp/nb-version
	getversion
else
	dialog --backtitle "$TITLE" --menu "Choose a version to download:" 20 70 13 \
	32 "Core 5.x - 32-bit" \
	64 "Core 5.x - 64-bit" 2>/tmp/nb-version
	getversion
fi
if [ $DISTRO != "grub4dos" ];then
	askforopts
fi
#Now for downloading.
if [ $DISTRO = "grub4dos" ];then
	if [ "$VERSION" = "0.4.4-2009-06-20" ];then
		wget http://download.gna.org/grub4dos/grub4dos-$VERSION.zip -O /tmp/g4d.zip
		unzip /tmp/g4d.zip -d /tmp
		rm /tmp/g4d.zip
		mv /tmp/grub4dos-*/grub.exe /tmp/nb-linux
		rm -r /tmp/grub4dos-*
	else
		wget -O /tmp/nb-linux http://download.tuxfamily.org/netbootcd/grub4dos-$VERSION/grub.exe
	fi
	true>/tmp/nb-initrd
elif [ $DISTRO = "core" ] || [ $DISTRO = "tinycore" ] || [ $DISTRO = "gparted" ];then
	if [ "$VERSION" == "64" ];then
		APPEND="64"
	else
		APPEND=""
	fi
	wget http://distro.ibiblio.org/tinycorelinux/5.x/x86/release/distribution_files/vmlinuz$APPEND -O /tmp/nb-linux
	wget http://distro.ibiblio.org/tinycorelinux/5.x/x86/release/distribution_files/core$APPEND.gz -O /tmp/nb-initrd
	if [ $DISTRO = "tinycore" ] || [ $DISTRO = "gparted" ];then
		mkdir -p /tmp/build
		cd /tmp/build
		gzip -cd /tmp/nb-initrd | cpio -id
		echo '#!/bin/sh
		echo "Waiting for internet connection (will keep trying indefinitely)"
		echo -n "Testing example.com"
		[ -f /tmp/internet-is-up ]
		while [ $? != 0 ];do
			sleep 0.1
			echo -n "."
			wget -q --spider http://www.example.com > /dev/null
		done
		echo > /tmp/internet-is-up' > script.sh
		for i in Xvesa Xlibs Xprogs wbar fltk-1.10 flwm_topside;do
			echo "tce-load -wi $i" >> script.sh
		done
		if [ $DISTRO = "gparted" ];then
			for i in gparted ntfsprogs dosfstools reiserfsprogs;do
				echo "tce-load -wi $i" >> script.sh
			done
		fi
		chmod +x script.sh
		echo "/script.sh && startx" >> etc/skel/.profile
		find . | cpio -o -H newc | gzip -c > /tmp/nb-initrd
		cd -
		rm -rf /tmp/build
	fi
fi
}

dialog --backtitle "$TITLE" --menu "What would you like to do?" 16 70 9 \
install "Install a Linux system" \
utils "Download and run boot-time utilities" \
download "Get newest script from the NetbootCD website" \
ipaddr "View/release IP address" \
script "Run a SYSLINUX .cfg file from the CD" \
quit "Quit to prompt (do not reboot)" 2>/tmp/nb-mainmenu

MAINMENU=$(cat /tmp/nb-mainmenu)
rm /tmp/nb-mainmenu
if [ $MAINMENU = quit ];then
	exit 1
fi
#We are going to need /tmp/nb-options empty later.
true>/tmp/nb-options
if [ $MAINMENU = "download" ];then
if wget -O /tmp/nbscript.sh http://downloads.tuxfamily.org/netbootcd/nbscript.sh;then
	chmod +x /tmp/nbscript.sh
	exec /tmp/nbscript.sh
else
	rm /tmp/nbscript.sh
	echo "Downloading the new script was not successful."
	exit 1
fi
fi
if [ $MAINMENU = "utils" ];then
	utilsmenu
fi
if [ $MAINMENU = "install" ];then
	installmenu
fi
if [ $MAINMENU = "ipaddr" ];then
  dialog --inputbox "Network interface:" 8 30 "eth0" 2>/tmp/nb-interface
  ifconfig $(cat /tmp/nb-interface)
  answer="invalid"
  while [ $? == 0 ];do
    read -p "Release IP address with \"killall -SIGUSR2 udhcpc\"? (Y/n) " answer
    if [ "$answer" == y ] || [ "$answer" == "" ];then
      killall -SIGUSR2 udhcpc
      echo "Released IP address."
      break
    elif [ "$answer" == n ];then
      break
    fi
  done
  exit
fi
if [ $MAINMENU = "script" ];then
	read-cfg.sh || echo "Could not find read-cfg.sh. This might be an older version of NetbootCD."
	exit 1 #If read-cfg works, this line will not be executed
fi
#This is what we will tell kexec.
if [ $MAINMENU != "script" ];then
	ARGS="-l /tmp/nb-linux --initrd=/tmp/nb-initrd $OPTIONS $CUSTOM"
else
	ARGS="-l /tmp/nb-linux --initrd=/tmp/nb-initrd $OPTIONS"
fi
if [ $DISTRO = "rhel-type-5" ];then
	ARGS=$ARGS" --args-linux"
fi
#This checks to make sure you are indeed on a TCB system.
if [ -d /home/tc ];then
	echo kexec $ARGS
	kexec $ARGS
	sleep 5
	sync
	kexec -e
fi
